@@ -22,6 +22,9 @@ force_axes_in_facets <- function() {
 no_legend_spacing <- function() {
   theme(legend.spacing.y = unit(0, "cm"))
 }
+reduce_legend_spacing <- function(cm) {
+  theme(legend.spacing.y = unit(-cm, "cm"))
+}
 space_legend_keys <- function(relative_size = 2, color = "white") {
   theme(legend.key = element_rect(size = rel(relative_size), color = color))
 }
