@@ -1,5 +1,8 @@
 #' Diagnostic plots for the No-U-Turn-Sampler (NUTS)
 #'
+#' Diagnostic plots for the No-U-Turn-Sampler (NUTS), the default MCMC algorithm
+#' used by Stan. See the \strong{Plot Descriptions} section, below.
+#'
 #' @name MCMC-nuts
 #' @aliases NUTS
 #' @family MCMC
@@ -23,12 +26,11 @@
 #'   \code{\link[gridExtra]{arrangeGrob}}) created from several ggplot objects,
 #'   except for \code{mcmc_nuts_energy}, which returns a ggplot object.
 #'
-#' @section Quick definitions:
-#' For more details see Stan Development Team (2016).
+#' @section Quick Definitions:
+#' For more details see Stan Development Team (2016) and Betancourt (2017).
 #' \itemize{
 #'   \item \code{accept_stat__}: the average acceptance probabilities of all
-#'   possible samples in the proposed tree (NUTS uses a slice sampling algorithm
-#'   for rejection).
+#'   possible samples in the proposed tree.
 #'   \item \code{divergent__}: the number of leapfrog transitions with diverging
 #'   error. Because NUTS terminates at the first divergence this will be either
 #'   0 or 1 for each iteration.
@@ -38,7 +40,7 @@
 #'   (base 2) of the number of leapfrog steps taken during the Hamiltonian
 #'   simulation.
 #'   \item \code{energy__}: the value of the Hamiltonian (up to an additive
-#'   constant) at each sample.
+#'   constant) at each iteration.
 #' }
 #'
 #' @section Plot Descriptions:
@@ -59,7 +61,7 @@
 #'    \item Violin plots of \code{lp__|divergent__=1} and
 #'      \code{lp__|divergent__=0}.
 #'    \item Violin plots of \code{accept_stat__|divergent__=1} and
-#'      \code{lp__|divergent__=0}.
+#'      \code{accept_stat__|divergent__=0}.
 #'    }
 #'   }
 #'   \item{\code{mcmc_nuts_stepsize}}{
@@ -89,8 +91,20 @@
 #' @template reference-nuts
 #' @template reference-stan-manual
 #'
-#' @seealso \code{\link{mcmc_trace}}, which will plot divergences on the
-#'   traceplot if the optional \code{divergences} argument is specified.
+#' @seealso
+#' \itemize{
+#' \item The \emph{Visual MCMC Diagnostics} vignette.
+#' \item Several other plotting functions in the \pkg{bayesplot}
+#' package that aren't NUTS-specific but take optional extra arguments
+#' if the model was fit using NUTS:
+#' \itemize{
+#'  \item \code{\link{mcmc_trace}} will plot divergences on the traceplot if the
+#'  optional \code{divergences} argument is specified.
+#'  \item \code{\link{mcmc_pairs}} will indicate which (if any) iterations
+#'  encountered a divergent transition or hit the maximum treedepth (rather than
+#'  terminated its evolution normally).
+#'  }
+#' }
 #'
 #' @examples
 #' \dontrun{
@@ -106,11 +120,11 @@
 #'
 #' color_scheme_set("red")
 #' mcmc_nuts_energy(np)
-#' mcmc_nuts_energy(np, binwidth = .25, alpha = .8)
-#' (energy_plot <- mcmc_nuts_energy(np, merge_chains = FALSE))
-#' energy_plot +
+#' mcmc_nuts_energy(np, merge_chains = TRUE, binwidth = .15)
+#' mcmc_nuts_energy(np) +
 #'  facet_wrap(~ Chain, nrow = 1) +
-#'  coord_fixed(ratio = 150)
+#'  coord_fixed(ratio = 150) +
+#'  ggtitle("NUTS Energy Diagnostic")
 #' }
 #'
 NULL
@@ -120,108 +134,108 @@ NULL
 #' @export
 #' @template args-hist
 #'
-mcmc_nuts_acceptance <- function(x, lp, chain = NULL, ..., binwidth = NULL) {
-  suggested_package("gridExtra")
-  check_ignored_arguments(...)
+mcmc_nuts_acceptance <-
+  function(x,
+           lp,
+           chain = NULL,
+           ...,
+           binwidth = NULL) {
+    suggested_package("gridExtra")
+    check_ignored_arguments(...)
 
-  x <- validate_nuts_data_frame(x, lp)
-  n_chain <- length(unique(lp$Chain))
-  chain <- validate_enough_chains(chain, n_chain)
-  overlay_chain <- !is.null(chain)
+    x <- validate_nuts_data_frame(x, lp)
+    n_chain <- length(unique(lp$Chain))
+    chain <- validate_enough_chains(chain, n_chain)
+    overlay_chain <- !is.null(chain)
 
-  accept_stat <- dplyr::filter_(x, ~ Parameter == "accept_stat__")
-  data <- suppressWarnings(dplyr::bind_rows(
-    accept_stat,
-    data.frame(lp, Parameter = "lp__")
-  ))
-
-  grp_par <- dplyr::group_by_(data, ~ Parameter)
-  stats_par <-
-    dplyr::summarise_(grp_par,
-                      Mean = ~ mean(Value),
-                      Median = ~ median(Value))
-
-  hists <- ggplot(data, aes_(x = ~ Value, y = ~ ..density..)) +
-    geom_histogram(
-      fill = get_color("l"),
-      color = get_color("lh"),
-      size = .25,
-      na.rm = TRUE,
-      binwidth = binwidth
+    accept_stat <- filter_(x, ~ Parameter == "accept_stat__")
+    data <- suppressWarnings(
+      dplyr::bind_rows(accept_stat, data.frame(lp, Parameter = "lp__"))
     )
 
-  if (!overlay_chain) {
-    hists <- hists +
-      geom_vline(
-        aes_(xintercept = ~ Mean),
-        data = stats_par,
-        color = get_color("dh")
-      ) +
-      geom_vline(
-        aes_(xintercept = ~ Median),
-        data = stats_par,
-        color = get_color("d"),
-        linetype = 2
-      )
-  }
-  hists <- hists +
-    dont_expand_y_axis(c(0.005, 0)) +
-    facet_wrap(~ Parameter, scales = "free") +
-    theme_default() +
-    yaxis_text(FALSE) +
-    yaxis_title(FALSE) +
-    yaxis_ticks(FALSE) +
-    xaxis_title(FALSE)
+    grp_par <- group_by_(data, ~ Parameter)
+    stats_par <- summarise_(grp_par,
+                            Mean = ~ mean(Value),
+                            Median = ~ median(Value))
 
-  scatter <- ggplot(NULL) +
-    geom_point(
-      aes_(x = ~ accept_stat$Value, y = ~ lp$Value),
-      shape = 21,
-      fill = get_color(ifelse(overlay_chain, "l", "m")),
-      color = get_color(ifelse(overlay_chain, "lh", "mh")),
-      alpha = 0.75
-    ) +
-    labs(x = "accept_stat__", y = "lp__") +
-    theme_default()
-
-
-  if (overlay_chain) {
-    hists <- hists +
+    hists <- ggplot(data, aes_(x = ~ Value, y = ~ ..density..)) +
       geom_histogram(
-        data = dplyr::filter_(data, ~Chain == chain),
-        fill = get_color("d"),
-        color = NA,
-        alpha = 0.5,
+        fill = get_color("l"),
+        color = get_color("lh"),
+        size = .25,
         na.rm = TRUE,
         binwidth = binwidth
       )
 
-    scatter <- scatter +
-      geom_point(
-        mapping = aes_(
-          x = ~ accept_stat$Value[accept_stat$Chain == chain],
-          y = ~ lp$Value[lp$Chain == chain]
-        ),
-        color = get_color("d"),
-        alpha = 0.5
-      )
-  }
+    if (!overlay_chain) {
+      hists <- hists +
+        geom_vline(
+          aes_(xintercept = ~ Mean),
+          data = stats_par,
+          color = get_color("dh")
+        ) +
+        geom_vline(
+          aes_(xintercept = ~ Median),
+          data = stats_par,
+          color = get_color("d"),
+          linetype = 2
+        )
+    }
+    hists <- hists +
+      dont_expand_y_axis(c(0.005, 0)) +
+      facet_wrap(~ Parameter, scales = "free") +
+      theme_default() +
+      yaxis_text(FALSE) +
+      yaxis_title(FALSE) +
+      yaxis_ticks(FALSE) +
+      xaxis_title(FALSE)
 
-  nuts_plot <- gridExtra::arrangeGrob(
-    hists,
-    gridExtra::arrangeGrob(empty_grob()),
-    gridExtra::arrangeGrob(
-      empty_grob(),
-      scatter,
-      empty_grob(),
-      ncol = 3,
-      widths = c(1, 3, 1)
-    ),
-    nrow = 3,
-    heights = c(1, 0.1, 1)
-  )
-  as_bayesplot_grid(nuts_plot)
-}
+    scatter <- ggplot(NULL) +
+      geom_point(
+        aes_(x = ~ accept_stat$Value, y = ~ lp$Value),
+        alpha = 0.75,
+        shape = 21,
+        fill = get_color(ifelse(overlay_chain, "l", "m")),
+        color = get_color(ifelse(overlay_chain, "lh", "mh"))
+      ) +
+      labs(x = "accept_stat__", y = "lp__") +
+      theme_default()
+
+    if (overlay_chain) {
+      hists <- hists +
+        geom_histogram(
+          data = filter_(data, ~ Chain == chain),
+          fill = get_color("d"),
+          color = NA,
+          alpha = 0.5,
+          na.rm = TRUE,
+          binwidth = binwidth
+        )
+
+      scatter <- scatter +
+        geom_point(
+          aes_(x = ~ accept_stat$Value[accept_stat$Chain == chain],
+               y = ~ lp$Value[lp$Chain == chain]),
+          color = get_color("d"),
+          alpha = 0.5
+        )
+    }
+
+    nuts_plot <- gridExtra::arrangeGrob(
+      hists,
+      gridExtra::arrangeGrob(empty_grob()),
+      gridExtra::arrangeGrob(
+        empty_grob(),
+        scatter,
+        empty_grob(),
+        ncol = 3,
+        widths = c(1, 3, 1)
+      ),
+      nrow = 3,
+      heights = c(1, 0.1, 1)
+    )
+    as_bayesplot_grid(nuts_plot)
+  }
 
 
 #' @rdname MCMC-nuts
@@ -235,33 +249,21 @@ mcmc_nuts_divergence <- function(x, lp, chain = NULL, ...) {
   chain <- validate_enough_chains(chain, n_chain)
   overlay_chain <- !is.null(chain)
 
-  accept_stat <- dplyr::filter_(x, ~ Parameter == "accept_stat__")
-  divergent <- dplyr::filter_(x, ~ Parameter == "divergent__")
+  accept_stat <- filter_(x, ~ Parameter == "accept_stat__")
+  divergent <- filter_(x, ~ Parameter == "divergent__")
   divergent$Value <- factor(divergent$Value, levels = c(0, 1),
                             labels = c("No divergence", "Divergence"))
 
   violin_lp_data <- data.frame(divergent, lp = lp$Value)
-  violin_lp <- ggplot(
-    violin_lp_data,
-    aes_(x = ~Value, y = ~lp)
-  ) +
-    geom_violin(
-      fill = get_color("l"),
-      color = get_color("lh")
-    ) +
+  violin_lp <- ggplot(violin_lp_data, aes_(x = ~ Value, y = ~ lp)) +
+    geom_violin(fill = get_color("l"), color = get_color("lh")) +
     ylab("lp__") +
     theme_default() +
     xaxis_title(FALSE)
 
   violin_accept_stat_data <- data.frame(divergent, as = accept_stat$Value)
-  violin_accept_stat <- ggplot(
-    violin_accept_stat_data,
-    aes_(x = ~Value, y = ~as)
-  ) +
-    geom_violin(
-      fill = get_color("l"),
-      color = get_color("lh")
-    ) +
+  violin_accept_stat <- ggplot(violin_accept_stat_data, aes_(x = ~ Value, y = ~ as)) +
+    geom_violin(fill = get_color("l"), color = get_color("lh")) +
     ylab("accept_stat__") +
     scale_y_continuous(limits = c(NA, 1.05)) +
     theme_default() +
@@ -276,15 +278,12 @@ mcmc_nuts_divergence <- function(x, lp, chain = NULL, ...) {
 
     div_count_by_chain <-
       table(divergent$Value, divergent$Chain)["Divergence", chain]
-    div_count_label <- paste0(div_count_label, " (", div_count_by_chain,
-                              " from chain ", chain, ")")
+    div_count_label <-
+      paste0(div_count_label, " (", div_count_by_chain,
+             " from chain ", chain, ")")
   }
   violin_lp <- violin_lp + labs(subtitle = div_count_label)
-  nuts_plot <- gridExtra::arrangeGrob(
-    violin_lp,
-    violin_accept_stat,
-    nrow = 2
-  )
+  nuts_plot <- gridExtra::arrangeGrob(violin_lp, violin_accept_stat, nrow = 2)
   as_bayesplot_grid(nuts_plot)
 }
 
@@ -301,12 +300,11 @@ mcmc_nuts_stepsize <- function(x, lp, chain = NULL, ...) {
   chain <- validate_enough_chains(chain, n_chain)
   overlay_chain <- !is.null(chain)
 
-  stepsize <- dplyr::filter_(x, ~ Parameter == "stepsize__")
-  accept_stat <- dplyr::filter_(x, ~ Parameter == "accept_stat__")
+  stepsize <- filter_(x, ~ Parameter == "stepsize__")
+  accept_stat <- filter_(x, ~ Parameter == "accept_stat__")
 
-  stepsize_by_chain <-
-    dplyr::summarise_(dplyr::group_by_(stepsize, ~Chain),
-                      ss = ~first(Value))
+  stepsize_by_chain <- summarise_(group_by_(stepsize, ~Chain),
+                                  ss = ~first(Value))
   stepsize_labels <-
     scale_x_discrete(labels = with(
       dplyr::arrange_(stepsize_by_chain, ~ ss),
@@ -314,14 +312,8 @@ mcmc_nuts_stepsize <- function(x, lp, chain = NULL, ...) {
     ))
 
   violin_lp_data <- dplyr::left_join(lp, stepsize_by_chain, by = "Chain")
-  violin_lp <- ggplot(
-    violin_lp_data,
-    aes_(x = ~as.factor(ss), y = ~Value)
-  ) +
-    geom_violin(
-      fill = get_color("l"),
-      color = get_color("lh")
-    ) +
+  violin_lp <- ggplot(violin_lp_data, aes_(x = ~as.factor(ss), y = ~Value)) +
+    geom_violin(fill = get_color("l"), color = get_color("lh")) +
     ylab("lp__") +
     stepsize_labels +
     theme_default() +
@@ -329,12 +321,9 @@ mcmc_nuts_stepsize <- function(x, lp, chain = NULL, ...) {
 
   violin_accept_stat_data <-
     dplyr::left_join(accept_stat, stepsize_by_chain, by = "Chain")
-  violin_accept_stat <- ggplot(violin_accept_stat_data,
-                               aes_(x = ~as.factor(ss), y = ~Value)) +
-    geom_violin(
-      fill = get_color("l"),
-      color = get_color("lh")
-    ) +
+  violin_accept_stat <-
+    ggplot(violin_accept_stat_data, aes_(x = ~as.factor(ss), y = ~Value)) +
+    geom_violin(fill = get_color("l"), color = get_color("lh")) +
     ylab("accept_stat__") +
     scale_y_continuous(limits = c(NA, 1.05)) +
     stepsize_labels +
@@ -347,11 +336,7 @@ mcmc_nuts_stepsize <- function(x, lp, chain = NULL, ...) {
     violin_accept_stat <- violin_accept_stat +
       chain_violin(violin_accept_stat_data, chain)
   }
-  nuts_plot <- gridExtra::arrangeGrob(
-    violin_lp,
-    violin_accept_stat,
-    nrow = 2
-  )
+  nuts_plot <- gridExtra::arrangeGrob(violin_lp, violin_accept_stat, nrow = 2)
   as_bayesplot_grid(nuts_plot)
 }
 
@@ -367,8 +352,8 @@ mcmc_nuts_treedepth <- function(x, lp, chain = NULL, ...) {
   chain <- validate_enough_chains(chain, n_chain)
   overlay_chain <- !is.null(chain)
 
-  treedepth <- dplyr::filter_(x, ~ Parameter == "treedepth__")
-  accept_stat <- dplyr::filter_(x, ~ Parameter == "accept_stat__")
+  treedepth <- filter_(x, ~ Parameter == "treedepth__")
+  accept_stat <- filter_(x, ~ Parameter == "accept_stat__")
 
   hist_td <- ggplot(treedepth, aes_(x = ~ Value, y = ~ ..density..)) +
     geom_histogram(
@@ -387,16 +372,14 @@ mcmc_nuts_treedepth <- function(x, lp, chain = NULL, ...) {
   violin_lp_data <- data.frame(treedepth, lp = lp$Value)
   violin_lp <-
     ggplot(violin_lp_data, aes_(x = ~ factor(Value), y = ~ lp)) +
-    geom_violin(fill = get_color("l"),
-                color = get_color("lh")) +
+    geom_violin(fill = get_color("l"), color = get_color("lh")) +
     labs(x = "treedepth__", y = "lp__") +
     theme_default()
 
   violin_accept_stat_data <- data.frame(treedepth, as = accept_stat$Value)
   violin_accept_stat <-
     ggplot(violin_accept_stat_data, aes_(x = ~ factor(Value), y = ~ as)) +
-    geom_violin(fill = get_color("l"),
-                color = get_color("lh")) +
+    geom_violin(fill = get_color("l"), color = get_color("lh")) +
     labs(x = "treedepth__", y = "accept_stat__") +
     scale_y_continuous(breaks = c(0, 0.5, 1)) +
     theme_default()
@@ -404,7 +387,7 @@ mcmc_nuts_treedepth <- function(x, lp, chain = NULL, ...) {
   if (overlay_chain) {
     hist_td <- hist_td +
       geom_histogram(
-        data = dplyr::filter_(treedepth, ~Chain == chain),
+        data = filter_(treedepth, ~Chain == chain),
         fill = get_color("d"),
         color = NA,
         alpha = 0.5,
@@ -442,14 +425,15 @@ mcmc_nuts_treedepth <- function(x, lp, chain = NULL, ...) {
 #' @param alpha For \code{mcmc_nuts_energy} only, the transparency (alpha) level
 #'   in [0,1] used for the overlaid histogram.
 #' @param merge_chains For \code{mcmc_nuts_energy} only, should all chains be
-#'   merged or displayed separately?
+#'   merged or displayed separately? The default is \code{FALSE}, i.e., to show
+#'   the chains separately.
 #'
 mcmc_nuts_energy <-
   function(x,
            ...,
            binwidth = NULL,
            alpha = 0.5,
-           merge_chains = TRUE) {
+           merge_chains = FALSE) {
     check_ignored_arguments(...)
 
     x <- validate_nuts_data_frame(x)
@@ -534,7 +518,9 @@ validate_nuts_data_frame <- function(x, lp) {
       paste(valid_cols, collapse = ", ")
     )
 
-  if (!missing(lp)) {
+  if (missing(lp))
+    lp <- NULL
+  if (!is.null(lp)) {
     if (!is.data.frame(lp))
       stop("lp should be in a data frame.")
 
